@@ -28,8 +28,6 @@ pub mod cloudiot_device_request;
 pub use self::cloudiot_device_request::CloudiotDeviceRequest;
 pub mod command_enum;
 pub use self::command_enum::CommandEnum;
-pub mod config_type_enum;
-pub use self::config_type_enum::ConfigTypeEnum;
 pub mod detail_response;
 pub use self::detail_response::DetailResponse;
 pub mod device;
@@ -38,6 +36,8 @@ pub mod device_calibration;
 pub use self::device_calibration::DeviceCalibration;
 pub mod device_calibration_request;
 pub use self::device_calibration_request::DeviceCalibrationRequest;
+pub mod device_release_channel;
+pub use self::device_release_channel::DeviceReleaseChannel;
 pub mod device_request;
 pub use self::device_request::DeviceRequest;
 pub mod email_auth_request;
@@ -60,10 +60,18 @@ pub mod janus_auth;
 pub use self::janus_auth::JanusAuth;
 pub mod janus_auth_request;
 pub use self::janus_auth_request::JanusAuthRequest;
+pub mod janus_config_type;
+pub use self::janus_config_type::JanusConfigType;
+pub mod janus_stream;
+pub use self::janus_stream::JanusStream;
+pub mod janus_stream_request;
+pub use self::janus_stream_request::JanusStreamRequest;
 pub mod janus_task;
 pub use self::janus_task::JanusTask;
 pub mod janus_task_request;
 pub use self::janus_task_request::JanusTaskRequest;
+pub mod janus_task_type;
+pub use self::janus_task_type::JanusTaskType;
 pub mod mobile_auth_request;
 pub use self::mobile_auth_request::MobileAuthRequest;
 pub mod model_artifact;
@@ -152,6 +160,8 @@ pub mod paginated_gcode_file_list;
 pub use self::paginated_gcode_file_list::PaginatedGcodeFileList;
 pub mod paginated_janus_auth_list;
 pub use self::paginated_janus_auth_list::PaginatedJanusAuthList;
+pub mod paginated_janus_stream_list;
+pub use self::paginated_janus_stream_list::PaginatedJanusStreamList;
 pub mod paginated_model_artifact_list;
 pub use self::paginated_model_artifact_list::PaginatedModelArtifactList;
 pub mod paginated_octo_print_backup_list;
@@ -202,6 +212,8 @@ pub mod patched_device_calibration_request;
 pub use self::patched_device_calibration_request::PatchedDeviceCalibrationRequest;
 pub mod patched_device_request;
 pub use self::patched_device_request::PatchedDeviceRequest;
+pub mod patched_janus_stream_request;
+pub use self::patched_janus_stream_request::PatchedJanusStreamRequest;
 pub mod patched_octo_print_device_request;
 pub use self::patched_octo_print_device_request::PatchedOctoPrintDeviceRequest;
 pub mod patched_polymorphic_event_request;
@@ -260,8 +272,6 @@ pub mod public_key;
 pub use self::public_key::PublicKey;
 pub mod public_key_request;
 pub use self::public_key_request::PublicKeyRequest;
-pub mod release_channel_enum;
-pub use self::release_channel_enum::ReleaseChannelEnum;
 pub mod remote_command_event;
 pub use self::remote_command_event::RemoteCommandEvent;
 pub mod remote_command_event_event_type_enum;
@@ -284,10 +294,8 @@ pub mod task_status;
 pub use self::task_status::TaskStatus;
 pub mod task_status_request;
 pub use self::task_status_request::TaskStatusRequest;
-pub mod task_status_status_enum;
-pub use self::task_status_status_enum::TaskStatusStatusEnum;
-pub mod task_type_enum;
-pub use self::task_type_enum::TaskTypeEnum;
+pub mod task_status_type;
+pub use self::task_status_type::TaskStatusType;
 pub mod telemetry_event;
 pub use self::telemetry_event::TelemetryEvent;
 pub mod telemetry_event_polymorphic;
